# Flask-Milligram

[Milligram](https://milligram.io/) — a minimalist CSS framework — helper for Jinja2 template engine in Flask.


## Links

* [Documentation](https://flask-milligram.readthedocs.io)
* [Example Application](https://github.com/ImJuanan/flask-milligram/tree/master/examples)


## Example

![flask-milligram example](images/example.png)
Run the example application, see [here](https://flask-milligram.readthedocs.io/en/latest/examples.html).


## License

This project is licensed under the MIT License (see the
`LICENSE` file for details).
